@@ -6,6 +6,6 @@
  */
 void F77_SUB(rndstart)(void) { GetRNGstate(); }
 void F77_SUB(rndend)(void) { PutRNGstate(); }
-float F77_SUB(random)() { return unif_rand(); }
+float F77_SUB(random)() { return (float)unif_rand(); }
 
 
